* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF;

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
*******      BEGIN HOFFMAN CHAPTER 2 DATA IMPORT AND MANIPULATION        *******;  
********************************************************************************;

* Define global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
%LET filesave= C:\Dropbox\24_PSQF6243\PSQF6243_Example4b;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* IMPORT chapter 2 example data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example4b";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\Example4b_Data.xlsx" 
            OUT=work.Example4b DBMS=XLSX REPLACE; 
     SHEET="Example4b"; 
     GETNAMES=YES; 
RUN;

* Prepare data for analysis;
DATA work.Example4b; SET work.Example4b;
* Center quantitative predictors near their means;
  age85 = age - 85;
  grip9 = grip - 9;
* Create 2 indicator-dummy-coded binary predictors for 3 dementia groups;
  demNF=.; demNC=.; * Create two new empty variables;
  IF demgroup=1 THEN DO; demNF=0; demNC=0; END; * Replace each for none group;
  IF demgroup=2 THEN DO; demNF=1; demNC=0; END; * Replace each for future group;
  IF demgroup=3 THEN DO; demNF=0; demNC=1; END; * Replace each for current group;
* Label new variables  note semi-colon is only at the end of ALL labels;
  LABEL   
  age85=     "age85: Age in Years (0=85)"
  grip9=     "grip9: Grip Strength in Pounds (0=9)"
  sexMW=     "sexMW: Sex (0=M, 1=W)"
  demNF=     "demNF: Dementia Contrast for None=0 vs Future=1"
  demNC=     "demNC: Dementia Contrast for None=0 vs Current=1"
  cognition= "cognition: Cognition Outcome"
  demgroup=  "demgroup: Dementia Group 1N 2F 3C";
* Select cases complete on all variables to be used;
  IF NMISS(cognition,age,grip,sexMW,demgroup)>0 THEN DELETE;
RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example4b_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

********************************************************************************;
*******           UNIVARIATE DESCRIPTION AND BIVARIATE ANALYSES          *******;
********************************************************************************;

TITLE "SAS Descriptive Statistics for Quantitative Variables";
PROC MEANS NONOBS NDEC=3 MEAN STDDEV VAR MIN MAX DATA=work.Example4b; 
     VAR cognition age grip sexMW; 
RUN; TITLE;

TITLE "SAS Descriptive Statistics for Categorical Variables"; 
PROC FREQ DATA=work.Example4b;
     TABLE sexMW demgroup;
RUN; TITLE;

TITLE "SAS Bivariate Correlations (btw, OUT saves corrs to dataset)";
PROC CORR NOSIMPLE DATA=work.Example4b OUT=work.Corrs;
     VAR cognition age grip sexMW; 
RUN; TITLE;

TITLE "SAS Linear + Quadratic Age (0=85) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 age85*age85 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Linear + Quadratic Grip (0=9) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = grip9 grip9*grip9 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;


* Save model name as macro variable to be replaced by &model. everywhere below;
%LET model = DemOnly;

TITLE "SAS 3-Category Dementia Group (Ref=None) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = demNF demNC / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
     ESTIMATE "Cognition Mean: None"         intercept 1 demNF  0 demNC  0; * beta0;
     ESTIMATE "Cognition Mean: Future"       intercept 1 demNF  1 demNC  0; * beta0+beta1;
     ESTIMATE "Cognition Mean: Current"      intercept 1 demNF  0 demNC  1; * beta0+beta2;
     ESTIMATE "Mean Diff: None vs. Future"               demNF  1 demNC  0; * beta1;
     ESTIMATE "Mean Diff: None vs. Current"              demNF  0 demNC  1; * beta2;
     ESTIMATE "Mean Diff: Future vs. Current"            demNF -1 demNC  1; * beta2-beta1;
* Save DF, R2, and fixed effects as SAS dataset to do math on them;
     ODS OUTPUT OverallANOVA=work.&model.DF FitStatistics=work.&model.R2
                Estimates=work.&model.Estimates; 
RUN; QUIT; TITLE;
* Save denominator DF to macro variable;
DATA work.&model.DF; SET work.&model.DF;
     IF _N_=2 THEN CALL SYMPUT("&model._DF_den",DF); 
RUN;
* Save R2 to macro variable;
DATA work.&model.R2; SET work.&model.R2;
     CALL SYMPUT("&model._R2",Rsquare); 
RUN;
* Compute effect sizes: partial (Cohen) d, partial r, and semi-partial r;
DATA work.&model.Estimates; SET work.&model.Estimates;
* Cohen partial d not given anywhere in output;
  PartialD=(2*tvalue)/SQRT(&&&model._DF_den.); 
* Partial R2 already given by SAS;
  PartialR=tvalue/SQRT((tvalue*tvalue)+&&&model._DF_den.);
* Semi-partial R2 already given by SAS;
  SemiPartialR=tvalue*SQRT((1-&&&model._R2.)/&&&model._DF_den.);
RUN;
* Print estimates with effect sizes;
TITLE "SAS &model. Model Solution and Effect Sizes";
PROC PRINT NOOBS DATA=work.&model.Estimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;    
     VAR Parameter Estimate StdErr tvalue probt PartialD PartialR SemiPartialR;  
RUN; TITLE;


********************************************************************************;
*******           SEQUENTIAL MODEL ANALYSES FOR UNIQUE EFFECTS           *******;
********************************************************************************;

TITLE "SAS Linear Age (0=85) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85  / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Add Linear Grip Strength (0=9) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 grip9  / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Add Binary Sex (0=M, 1=W) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 grip9 sexMW / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;


* Save model name as macro variable to be replaced by &model. everywhere below;
%LET model = Combined;

TITLE "SAS &model. Model Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 grip9 sexMW demNF demNC / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
     CONTRAST "F-Test DFnum=2 for Demgroup"      demNF  1, demNC  1; * For overall demgroup;
     CONTRAST "F-Test DFnum=2 for Age and Sex"   age85  1, sexMW  1; * For demographic vars;
     ESTIMATE "Mean Diff: Future vs. Current"    demNF -1  demNC  1; * beta5-beta4;
* Save DF, R2, and fixed effects as SAS dataset to do math on them;
     ODS OUTPUT OverallANOVA=work.&model.DF FitStatistics=work.&model.R2
                ParameterEstimates=work.&model.Fix Estimates=work.&model.Est; 
RUN; QUIT; TITLE; 
* Save denominator DF to macro variable;
DATA work.&model.DF; SET work.&model.DF;
     IF _N_=2 THEN CALL SYMPUT("&model._DF_den",DF); 
RUN;
* Save R2 to macro variable;
DATA work.&model.R2; SET work.&model.R2;
     CALL SYMPUT("&model._R2",Rsquare); 
RUN;
* Compute effect sizes: partial (Cohen) d, partial r, and semi-partial r;
DATA work.&model.Estimates; LENGTH Parameter $50;
     SET work.&model.Fix work.&model.Est;
* Cohen partial d not given anywhere in output;
  PartialD=(2*tvalue)/SQRT(&&&model._DF_den.); 
* Partial R2 already given by SAS;
  PartialR=tvalue/SQRT((tvalue*tvalue)+&&&model._DF_den.);
* Semi-partial R2 already given by SAS;
  SemiPartialR=tvalue*SQRT((1-&&&model._R2.)/&&&model._DF_den.);
RUN;
* Print estimates with effect sizes;
TITLE "SAS &model. Model Solution and Effect Sizes";
PROC PRINT NOOBS DATA=work.&model.Estimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;    
     VAR Parameter Estimate StdErr tvalue probt PartialD PartialR SemiPartialR; 
RUN; TITLE;


* Close output;
ODS RTF CLOSE;

