// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
******                  BEGIN IMPORT FOR CHAPTER 2 DATA                  *******
********************************************************************************

// Paste in the folder address where "Example4b_Data.xlsx" is saved between " "
cd "C:\Dropbox\24_PSQF6243\PSQF6243_Example4b"
// Using UIowa virtual desktop instead
//cd "\\Client\C:\Dropbox\24_PSQF6243\PSQF6243_Example4b"

// IMPORT Example4b.xlsx data from working directory using exact file name
// To change all variable names to lowercase, remove "case(preserve")
clear // Clear before means close any open data
import excel "Example4b_Data.xlsx", case(preserve) firstrow sheet("Example4b") clear 
// Clear after means re-import if it already exists (if need to start over)
   
// Center quantitative predictors near their means
gen age85 = age - 85
gen grip9 = grip - 9
// Create 2 indicator-dummy-coded binary predictors for 3 dementia groups
gen demNF=.  // Create 2 new empty variables 
gen demNC=.
// Replace for demgroup = none   
replace demNF=0 if demgroup==1
replace demNC=0 if demgroup==1
// Replace for demgroup = future 
replace demNF=1 if demgroup==2
replace demNC=0 if demgroup==2
// Replace for demgroup = current
replace demNF=0 if demgroup==3
replace demNC=1 if demgroup==3
// Label all variables
label variable age85     "age85: Age in Years (0=85)"
label variable grip9     "grip9: Grip Strength in Pounds (0=9)"
label variable sexMW     "sexMW: Sex (0=Men, 1=Women)"
label variable demNF     "demNF: Dementia Contrast for None=0 vs Future=1"
label variable demNC     "demNC: Dementia Contrast for None=0 vs Current=1"
label variable cognition "cognition: Cognition Outcome"
label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"

// Select cases complete on all variables to be used
egen nmiss=rowmiss(cognition age grip sexMW demgroup)
drop if nmiss>0

    
********************************************************************************
*******           UNIVARIATE DESCRIPTION AND BIVARIATE ANALYSES          *******
********************************************************************************

// Open external file to save results to
log using Example4b_STATA_Output.log, replace

display "STATA Descriptive Statistics for Quantitative Variables"
summarize cognition age grip sexMW

display "STATA Descriptive Statistics for Categorical Variables"
tabulate sexMW 
tabulate demgroup
       
display "STATA Bivariate Correlations"
pwcorr cognition age grip sexMW, sig 

display "STATA Linear + Quadratic Age (0=85) Predicting Cognition"
regress cognition c.age85 c.age85#c.age85, level(95)

display "STATA Linear + Quadratic Grip (0=9) Predicting Cognition"
regress cognition c.grip9 c.grip9#c.grip9, level(95)

display "STATA Dementia Group (Ref=None) Predicting Cognition"
regress cognition c.demNF c.demNC, level(95)              
estimates store DemOnly       // Save all model results for R2 in effect sizes below
lincom _cons*1 + c.demNF*0 + c.demNC*0 // Cognition Mean for None    = beta0
lincom _cons*1 + c.demNF*1 + c.demNC*0 // Cognition Mean for Future  = beta0+beta1
lincom _cons*1 + c.demNF*0 + c.demNC*1 // Cognition Mean for Current = beta0+beta2

estimates restore DemOnly     // Restore model results for post-estimations below 
lincom c.demNF*1  + c.demNC*0 // Mean Diff: None vs. Future    = beta1
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial r = "        (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial r = "   (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.demNF*0  + c.demNC*1 // Mean Diff: None vs. Current   = beta2
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial r = "        (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial r = "   (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.demNF*-1 + c.demNC*1 // Mean Diff: Future vs. Current = beta2-beta1
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial r = "        (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial r = "   (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
   

********************************************************************************
*******           SEQUENTIAL MODEL ANALYSES FOR UNIQUE EFFECTS           *******
********************************************************************************
   
display "STATA code for how to use nestreg to get F-test for R2 change"
// Format below is outcome (what to add to model at each step)
nestreg: regress cognition (age85) (grip9) (sexMW) (demNF demNC) 
estimates store Combined    // Save all model results for R2 in effect sizes below
ereturn list                // See what has been stored automatically 
global SSresidual = e(rss)  // Save last model SS residual for effect sizes below
global SSfull = e(mss)      // Save last model SS model for effect sizes below

display "F-Test DFnum=2 for Age and Sex"
test (c.age85=0)(c.sexMW=0)  // Demographic variables  
display "STATA Reduced Model to Get Model SS from Omitting Age and Sex"
quietly regress cognition c.grip9 c.demNF c.demNC, level(95)
global  SSeffect = $SSfull - e(mss)
display "Partial R2 = "      $SSeffect/($SSeffect+$SSresidual)
display "Semi-Partial R2 = " $SSeffect/($SSfull+$SSresidual)
  
// Get partial correlations for age, grip, and sex (sr2 for dem slopes are not valid)
pcorr cognition c.age85 c.grip9 c.sexMW c.demNF c.demNC 
  
estimates restore Combined    // Restore model results for post-estimations below 
lincom c.sexMW*1              // Mean Diff: Men vs. Women = beta3
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
lincom c.demNF*1  + c.demNC*0 // Mean Diff: None vs. Future    = beta4
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
lincom c.demNF*0  + c.demNC*1 // Mean Diff: None vs. Current   = beta5
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
lincom c.demNF*-1 + c.demNC*1 // Mean Diff: Future vs. Current = beta5-beta4
   display "Partial d = "        (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial r = "        (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial r = "   (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))


// Close external file of saved results
log close


